# Unstract LLMWhisperer X2Text Adapter

## Env variables

The below env variables are resolved by LLMWhisperer adapter

| Variable                     | Description                                                                                  |
| ---------------------------- | -------------------------------------------------------------------------------------------- |
| `ADAPTER_LLMW_POLL_INTERVAL` | Time in seconds to wait before polling LLMWhisperer's status API. Defaults to 30s            |
| `ADAPTER_LLMW_MAX_POLLS`     | Total number of times to poll the status API. Defaults to 30                                 |
